Krstarica - najposećeniji internet sajt u Srbiji
Description: Najposećeniji sajt u Srbiji
Keywords: krstarica, srbija, rs, beograd, internet, ISP, provajder, dial up, pretraga, pretrazivac, posta, zivot, vesti, pricaonica, kurs, recnik, katalog, blog, igre, igrice, muzika, film, mp3, oglasi, reklamiranje, forum, horoskop, tv, zdravlje, recepti

Pretraži Krstaricu Pretraži internet

- Svi članci
- Vesti
- Forum
- Zabava
- Sport
- Ekonomija
- Život
- Zdravlje
- Kuvar
- Još ▾
  - Zabava
  - Sport
  - Ekonomija
  - Život
  - Zdravlje
  - Kuvar

### Li: Nastavak saradnje sa Srbijom u svim oblastima

BEOGRAD – U susret Samitu Kine i 16 zemalja centralne i jugoistočne Evrope kineski ambasador u Beogradu Li Mančang poručio je da Peking želi da nastavi prijateljsku saradnju sa Srbijom u svim oblastima...

### Dačić: Ukrajina je prioritet srpskog predsedavanja OEBS

BAZEL - Rešavanje krize u Ukrajini biće prioritet predstojećeg predsedavanja Srbije OEBS, rekao je danas u završnom izlaganju na zasedanju ministarskog saveta te organizacije u Bazelu srpski ministar spoljnih...

### Mogerini upozorava Rusiju zbog Balkana

"Očigledno je da sada postoje tenzije između Evropske unije i Ruske federacije. Ali mislim da je u interesu dve strane da nađemo i razvijemo puteve saradnje, a ne konfrontacije", rekla je Mogerini u obraćanju...

### Evropa je više od političke zajednice

BEOGRAD - Evropa je više od političke i ekonomske zajednice, ona je dinamični kulturni koncept u kojem se granice brišu, ocenili su večeras učesnici trodnevne "Beogradske debate o Evropi". Evropska unija, koja...

### Grafiti “OVK” i “Kosova” u porti manastira u Zočištu

ORAHOVAC - Na ogradi u porti manastira Sveti Vrači u Zočištu kod Orahovca, nepoznati počinioci ispisali su grafite “UCK“ (Oslobodilačka vojska Kosova) i "Kosovo“, što je Eparhija Raško-prizrenska ocenila kao...

### Najbolji čajevi za mršavljenje

Čajevi su bogati antioksidansima, polifenolima i ostalim zdravim sastojcima, pa su zato najbolji izbor kad poželite da se bacite na dijetu. Nekoliko šolja dnevno učiniće čuda za vašu liniju. ZELENI ČAJ...

### Zvezde pobedila u Valensiji za Top 16 fazu (VIDEO)

Košarkaši Crvene zvezde savladali su večeras u Valensiji istoimeni španski tim sa 77:68 (20:16, 22:21, 20:15, 15:16) i petom pobedom u D grupi Evrolige obezbedili plasman u Top 16 fazu. Utakmicu 8. kola...

### Najluđe i najbesmislenije selfie fotke na internetu

Ne, ni mi nismo uspeli da odgonetnemo šta je ovaj momak zaista želeo da postigne ovom fotografijom, a potpuno smo zapanjeni njenim elementima. Razumemo se. Svi prave selfije, naravno, samo su neki od...

### Omalovažena vrednost vojvođanskih šuma

Državna revizorska institucija objavila je juče da je Javno preduzeće „Vojvodinašume”, procenom da šume kojima gazduje vrede 6,7 milijardi dinara, višestruko potcenilo njihovu vrednost. Po reviziji...

### Šta dečaci stvarno rade kad ostanu sami kod kuće?

Mnogi se neće saglasiti a mnogi će prepoznati i sebe i druge. U svakom slučaju svi ćemo se dobro nasmejati – evo šašavih stvari koje muškarci zaista rade kada su sami kod kuće:

### Kakav superdeka: Ima 87 godina, a za 40 sekundi popne se na stenu visoku 14 metara!

VRNjAČKA BANjA - Sa punih 87 godina, Mladen Todorović je zasigurno najstariji aktivni sportski alpinista u Evropi koji još učestvuje na takmičenjima slobodnog penjanja. Na veštačku stenu visoku 14 metara...

### Džon Vik

Žanr: akcija, triler Trajanje: 101 min. Glavne uloge: Kijanu Rivs (Keanu Reeves), Majkl Nikvist (Michael Nyqvist), Alfi Alen (Alfie Allen), Viljem Dafo (Willem Dafoe), Brižet Mojnahan (Bridget...

### Crnogorski konzulat u Karlovcima dobio zeleno svetlo

Vlada Republike Srbije dala je saglasnost da se u Sremskim Karlovcima otvori generalni konzulat Crne Gore. Rešenje o davanju saglasnosti objavljeno je u „Službenom glasniku RS”, a Ministarstvo spoljnih poslova...

### Strah od gojaznosti nakon prestanka pušenja

Strah od nezdrave težine može biti razlog koji mnoge pušače sprečava da ostave cigarete. Nova studija pokazuje da čak i ako dodate nekoliko kilograma kada prestanete da pušite, vaše zdravlje će biti...

### "Brisel će nas suočiti sa priznavanjem Kosova"

Predsednik Srbije Tomislav Nikolić ocenio je da će Brisel suočiti Beograd sa priznavanjem Kosova u zamenu za nastavak evropskih integracija i da je to pitanje oko kojeg treba što pre postići nacionalni...

### Ćudljivost nije privlačna

Ima osoba koje su po prirodi ćudljive, sklone naglim promenama raspoloženja, a ta osobina postaje još izraženija u pubertetu, zbog hormonskih promena koje se dešavaju u organizmu. Ćudljivost ume da bude...

### Orahovac: Grafiti OVK i Kosova u porti manastira u Zočištu!

NA ogradi u porti manastira Sveti Vrači u Zočištu kod Orahovca, nepoznati počinioci ispisali su grafite UCK (Oslobodilačka vojska Kosova) i "Kosovo", što je Eparhija Raško-prizrenska ocenila kao novu...

### Madona novo lice Versace-a

PARIZ - Američka pevačica Madona (56) novo je lice Versace-ove kolekcije za proleće/leto 2015. godine, piše AFP. Posle nedavnog fotografisanja u toplesu za magazin "Intervju" koje je podelilo javnost, Madonu...

### Mediteranska ishrana čuva genetsku mladost

Mediteranska dijeta može da bude recept za dug život, jer, po svim pokazateljima, ona čini ljude genetski mlađim, kažu američki istraživači. Mešavina povrća, maslinovog ulja, sveže ribe i voća može da zaustavi...

### KOPI-PEJST ILI ŽIVOT: Lelujava plavo - bela istorija

Barokna razbokorenost i koloritno bogatstvo “jakog” jezika bile su osnovne poluge pozamašnog romana “Lutajući Bokelj” mladog pisca Nikole Malovića koji je, pre par godina, privukao popriličnu pažnju – i...

### Na Tajvanu pametni telefoni ugožavaju privatni život

TAJPEJ - Na Tajvanu 12 proizvođača mobilnih telefona se ne pridržava zakona u pogledu poštovanja privatnog života tako da bi se protiv njih mogle podneti krivične prijave kao i da im se zabrani prodaja...

### Kris Martin: Naredni album Coldplay-a biće poslednji (VIDEO)

Frontmen britanske grupe Coldplay Kris Martin nagovestio je da bi sedmi studijski album benda mogao da bude i poslednji. U emisiji Zejna Loua na Radiju 1, pevač je rekao da bi album koji će se nastaviti na...

### Zimske gume nisu svemoguće

Iako još nema snega, u pojedinim krajevima Srbije vozači su se već suočili sa otežanim uslovima saobraćaja zahvaljujući ledenoj kiši i olujnom vetru. Oni koji ne nameravaju da se odreknu automobila tokom zime...

Napišite komentar na novu početnu stranu

Katalog se nalazi na dnu ove kolone, kao i u levom meniju

## Najnovije vesti

- Priznanje Vučiću za govor pred Savetom bezbednosti

- Mobilizacija sećanja iz Velikog rata

- Slučaj Štrpci, Srbija poslala snažnu poruku

- Mogerini upozorava Rusiju zbog Balkana

- Pokret socijalista: DS podelio falsifikovane ugovore

Poslednja vest: 23:46

## Kurs dinara

- €121.216 • $97.9286 • £153.0892 • CHF100.7698

## Strip

- Ženama ne možeš ugoditi

## Horoskop

Čitaj više…Nije Vaš znak?

### Izaberite znak

## Najnovije sa Foruma

- Putevi , staze…

- ❤ D E C A ❤

- Zeleno kao….

- Slobodna volja je iluzija ?

- Stepenik do stepenika….

## Igre

- Sobics School 2

- Skytunes

- Himalayaya

- The Necronomicon Book of Dead Names

- Honey 82

## Vicevi

Zašto Perica ne jede zečetinu?
Ne voli brzu hranu.

Još viceva…

## Prodavnica

- ECDL DVD – 1.240 din

  Multimedijalni kursevi za Evropsku računarsku vozačku dozvolu (ECDL), u potpunosti prilagođeni nastavnom programu i nalaze se na spisku odobrene literature…

- Poslovni engleski – 1.200 din

  Multimedijalni kurs Business English predstavlja najsavremeniju metodu za samostalno učenje poslovnog engleskog jezika. Čak i ako vas ne zanima poslovna…

- Englesko – srpsko – engleski rečnik – 1.400 din

  Contact englesko-srpsko-engleski rečnik obuhvata nekoliko programa za prevođenje reči i teksta sa engleskog na srpski i sa srpskog na engleski jezik. Rečnik…

## Najnoviji oglasi

- MAN KING CENA 1700d, MAN KING, MAN KING PRODAJA, MAN KING SRBIJA, MAN KING BEOGRAD, MAN KING PRIRODAN PREPARAT, MAN KING POVOLJNO, MAN KING

- KAMAGRA GOLD 800d www.kamagragel.rs 0695553989

- KAMAGRA BOMBONE CENA 800 din www.kamagragel.rs 0695553989

- SUPER KAMAGRA PRODAJA CENA 11e www.kamagragel.rs 0695553989

- KAMAGRA SUMECE TABLETE CENA 11e www.kamagragel.rs 0695553989

## Katalog

- Biznis i ekonomija
  Firme Nekretnine Finansije Vozila
- Društvene nauke
  Istorija Ekonomija Pravo
- Društvo
  Ljudi Politika Dom i porodica Religija
- Zabava
  Video i film Igre Humor
- Zdravstvo
  Medicina Lekovi Ishrana
- Kompjuteri i Internet
  Internet Softver Igre WWW
- Korisne informacije
  Važni telefoni Taksi službe Apoteke
- Mediji
  Televizija i video Novine Časopisi
- Nauka
  Tehničke Prirodne Organizacije
- Obrazovanje
  Fakulteti Škole Biblioteke
- Regionalno
  Gradovi Opštine Regioni
- Sport
  Košarka Fudbal Org. i klubovi
- Turizam i putovanja
  Odredišta Agencije Ambasade
- Umetnost i kultura
  Književnost Pozorišta Muzika

Dodajte svoj sajt u katalog

## Sponzorisani linkovi

Ultra Screen Saver Maker – Create a screensaver!